import React, { useState} from 'react';
import ReactDOM from 'react-dom';
import { scaleLinear, scaleOrdinal, format, extent } from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';
import { ColorLegend } from './colorLegend';

const width = 960;
const menuHeight = 80;
const height = 500 - menuHeight;
const margin = { top: 10, right: 200, bottom: 65, left: 90 };
const xAxisLabelOffset = 50;
const yAxisLabelOffset = 45;

const attributes = [
  { value: 'new_cases', label: 'new cases' },
  { value: 'total_cases', label: 'total cases' },
  { value: 'new_cases_smoothed', label: 'newcases smoothed' },
  { value: 'total_deaths', label: 'total deaths' },
  { value: 'new_deaths', label: 'new deaths' },
  { value: 'new_deaths_smoothed', label: 'new deaths smoothed' }
];

const getLabel = value => {
  for (let i = 0; i < attributes.length; i++) {
    if (attributes[i].value === value) {
      return attributes[i].label;
    }
  }
};

const App = () => {
  const data = useData();

  const initialXAttribute = 'new_cases';
  const [xAttribute, setXAttribute] = useState(initialXAttribute);
  const xValue = d => d[xAttribute];
  const xAxisLabel = getLabel(xAttribute);

  const initialYAttribute = 'total_cases';
  const [yAttribute, setYAttribute] = useState(initialYAttribute);
  const yValue = d => d[yAttribute];
  const yAxisLabel = getLabel(yAttribute);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
  const siFormat = format('.2s');
  const xAxisTickFormat = tickValue => siFormat(tickValue).replace('G', 'B');
	const colorValue = d => d.continent	;
  const colorLegendLabel = 'Continent';
  
  //const filteredData = data.filter(d => d.Dateofmonth == 1);
  //console.log(filteredData)
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
	
 
  
  const yScale = scaleLinear()
//  	.domain([0,max(data, d => d.total_cases)])
    .domain(extent(data, yValue))
    .range([ innerHeight, 0])
  	.nice();

  const colorScale = scaleOrdinal()
    .domain(data.map(colorValue))
    .range(['red','gray','blue','green','orange','purple']);
  	//.range(['#E6842A', '#137B80', '#8E6C8A','#EA4C2A','#2AEA35','#2A6FEA']);
  
  
   //console.log(colorScale)
  
  return (
    
      <svg width={width} height={height}>
        <g transform={`translate(${margin.left},${margin.top})`}>
          <AxisBottom
            xScale={xScale}
            innerHeight={innerHeight}
            tickFormat={xAxisTickFormat}
            tickOffset={5}
          />
          <text
            className="axis-label"
            textAnchor="middle"
            transform={`translate(${-yAxisLabelOffset},${innerHeight /
              2}) rotate(-90)`}
          >
            {yAxisLabel}
          </text>
          <AxisLeft yScale={yScale} innerWidth={innerWidth} tickOffset={5} />
          <text
            className="axis-label"
            x={innerWidth / 2}
            y={innerHeight + xAxisLabelOffset}
            textAnchor="middle"
          >
            {xAxisLabel}
          </text>
          <g transform={`translate(${innerWidth + 60}, 60)`}>
          <text
            x={35}
            y={-25}
            className="axis-label"
            textAnchor="middle"
          >
            {colorLegendLabel}
          </text>
          <ColorLegend
            tickSpacing={22}
            tickTextOffset={12}
            tickSize={3}
            colorScale={colorScale}
          />
        </g>
        <Marks
          data={data}
          xScale={xScale}
          xValue={xValue}
          yScale={yScale}
          yValue={yValue}
          colorScale={colorScale}
          colorValue={colorValue}
          tooltipFormat={xAxisTickFormat}
          circleRadius={3}
        />
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
